==> qt6-wayland-6.0.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/Qt6WaylandCompositor/Qt6QWaylandXCompositeEglClientBufferIntegrationPluginAdditionalTargetInfo.cmake <==
# Additional target information for Qt6QWaylandXCompositeEglClientBufferIntegrationPlugin
if(NOT DEFINED QT_DEFAULT_IMPORT_CONFIGURATION)
    set(QT_DEFAULT_IMPORT_CONFIGURATION RELEASE)
endif()
get_target_property(_qt_imported_location Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin IMPORTED_LOCATION_RELEASE)
get_target_property(_qt_imported_implib Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin IMPORTED_IMPLIB_RELEASE)
get_target_property(_qt_imported_soname Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin IMPORTED_SONAME_RELEASE)
get_target_property(_qt_imported_location_default Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin IMPORTED_LOCATION_${QT_DEFAULT_IMPORT_CONFIGURATION})
get_target_property(_qt_imported_implib_default Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin IMPORTED_IMPLIB_${QT_DEFAULT_IMPORT_CONFIGURATION})
get_target_property(_qt_imported_soname_default Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin IMPORTED_SONAME_${QT_DEFAULT_IMPORT_CONFIGURATION})

# Import target "Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)

if(_qt_imported_location)
    set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin PROPERTY IMPORTED_LOCATION_RELWITHDEBINFO "${_qt_imported_location}")
endif()
if(_qt_imported_implib)
    set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin PROPERTY IMPORTED_IMPLIB_RELWITHDEBINFO "${_qt_imported_implib}")
endif()
if(_qt_imported_soname)
    set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin PROPERTY IMPORTED_SONAME_RELWITHDEBINFO "${_qt_imported_soname}")
endif()

# Import target "Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin" for configuration "MinSizeRel"
set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin APPEND PROPERTY IMPORTED_CONFIGURATIONS MINSIZEREL)

if(_qt_imported_location)
    set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin PROPERTY IMPORTED_LOCATION_MINSIZEREL "${_qt_imported_location}")
endif()
if(_qt_imported_implib)
    set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin PROPERTY IMPORTED_IMPLIB_MINSIZEREL "${_qt_imported_implib}")
endif()
if(_qt_imported_soname)
    set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin PROPERTY IMPORTED_SONAME_MINSIZEREL "${_qt_imported_soname}")
endif()

# Default configuration
if(_qt_imported_location_default)
    set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin PROPERTY IMPORTED_LOCATION "${_qt_imported_location_default}")
endif()
if(_qt_imported_implib_default)
    set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin PROPERTY IMPORTED_IMPLIB "${_qt_imported_implib_default}")
endif()
if(_qt_imported_soname_default)
    set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin PROPERTY IMPORTED_SONAME "${_qt_imported_soname_default}")
endif()

unset(_qt_imported_location)
unset(_qt_imported_location_default)
unset(_qt_imported_soname)
unset(_qt_imported_soname_default)

==> qt6-wayland-6.2.2-1-aarch64.pkg.tar.xz: usr/lib/cmake/Qt6WaylandCompositor/Qt6QWaylandXCompositeEglClientBufferIntegrationPluginAdditionalTargetInfo.cmake <==
# Additional target information for Qt6QWaylandXCompositeEglClientBufferIntegrationPlugin
if(NOT DEFINED QT_DEFAULT_IMPORT_CONFIGURATION)
    set(QT_DEFAULT_IMPORT_CONFIGURATION RELEASE)
endif()
__qt_internal_promote_target_to_global_checked(Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin)
get_target_property(_qt_imported_location Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin IMPORTED_LOCATION_RELEASE)
get_target_property(_qt_imported_location_default Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin IMPORTED_LOCATION_${QT_DEFAULT_IMPORT_CONFIGURATION})

# Import target "Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)

if(_qt_imported_location)
    set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin PROPERTY IMPORTED_LOCATION_RELWITHDEBINFO "${_qt_imported_location}")
endif()

# Import target "Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin" for configuration "MinSizeRel"
set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin APPEND PROPERTY IMPORTED_CONFIGURATIONS MINSIZEREL)

if(_qt_imported_location)
    set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin PROPERTY IMPORTED_LOCATION_MINSIZEREL "${_qt_imported_location}")
endif()

# Default configuration
if(_qt_imported_location_default)
    set_property(TARGET Qt6::QWaylandXCompositeEglClientBufferIntegrationPlugin PROPERTY IMPORTED_LOCATION "${_qt_imported_location_default}")
endif()

unset(_qt_imported_location)
unset(_qt_imported_location_default)
unset(_qt_imported_soname)
unset(_qt_imported_soname_default)
unset(_qt_imported_configs)
